@@ -596,7 +596,7 @@ comexec(t, tp, ap, flags)
 
 	  case CFUNC:			/* function call */
 	  {
-		volatile int old_xflag;
+/*		volatile int old_xflag; */
 		volatile Tflag old_inuse;
 		const char *volatile old_kshname;
 
@@ -648,8 +648,8 @@ comexec(t, tp, ap, flags)
 		 * bourne/posix functions are insane...
 		 */
 
-		old_xflag = Flag(FXTRACE);
-		Flag(FXTRACE) = tp->flag & TRACE ? TRUE : FALSE;
+/*		old_xflag = Flag(FXTRACE);
+ 		Flag(FXTRACE) = tp->flag & TRACE ? TRUE : FALSE; */
 
 		old_inuse = tp->flag & FINUSE;
 		tp->flag |= FINUSE;
@@ -662,7 +662,7 @@ comexec(t, tp, ap, flags)
 			i = LRETURN;
 		}
 		poshname = old_kshname;
-		Flag(FXTRACE) = old_xflag;
+/*		Flag(FXTRACE) = old_xflag; */
 		tp->flag = (tp->flag & ~FINUSE) | old_inuse;
 		/* Were we deleted while executing?  If so, free the execution
 		 * tree.  todo: Unfortunately, the table entry is never re-used
