@@ -292,29 +292,7 @@ yylex(int cf)
 			  case '`':
 				PUSH_STATE(SBQUOTE);
 				*wp++ = COMSUB;
-				/* Need to know if we are inside double quotes
-				 * since sh/at&t-ksh translate the \" to " in
-				 * "`..\"..`".
-				 * This is not done in posix mode (section
-				 * 3.2.3, Double Quotes: "The backquote shall
-				 * retain its special meaning introducing the
-				 * other form of command substitution (see
-				 * 3.6.3). The portion of the quoted string
-				 * from the initial backquote and the
-				 * characters up to the next backquote that
-				 * is not preceded by a backslash (having
-				 * escape characters removed) defines that
-				 * command whose output replaces `...` when
-				 * the word is expanded."
-				 * Section 3.6.3, Command Substitution:
-				 * "Within the backquoted style of command
-				 * substitution, backslash shall retain its
-				 * literal meaning, except when followed by
-				 * $ ` \.").
-				 */
 				statep->ls_sbquote.indquotes = 0;
-#ifdef SILLY_FEATURES
-				if (!Flag(FPOSIX)) {
 					Lex_state *s = statep;
 					Lex_state *base = state_info.base;
 					while (1) {
@@ -330,8 +308,6 @@ yylex(int cf)
 							break;
 						base = s-- - STATE_BSIZE;
 					}
-				}
-#endif /* SILLY_FEATURES */
 				break;
 			  default:
 				*wp++ = CHAR, *wp++ = c;
