@@ -177,8 +177,13 @@ int posh_builtin_cd(int argc, char **argv, int UNUSED(flags))
 			char *simplified;
 
 			simplified = canonicalize_file_name(Xstring(xs, xp));
-			rval = chdir(try = strdup(simplified));
-			free(simplified);
+			if (simplified != NULL) {
+				rval = chdir(try = strdup(simplified));
+				free(simplified);
+			}
+			else
+				rval = -1;
+
 		}
 	} while (rval < 0 && cdpath != (char *) 0);
 
